@@ -1,10 +1,9 @@
 import logging
-from threading import Thread
-import logging
-import websocket
-from typing import Optional
-from datetime import datetime
 import time
+from datetime import datetime
+from threading import Thread
+from typing import Optional
+import websocket
 
 from .rustplus_pb2 import AppMessage, AppRequest
 from ..structures import RustChatMessage
@@ -25,7 +24,7 @@ class RustWebsocket(websocket.WebSocket):
 
         super().__init__(enable_multithread=True)
 
-    def connect(self, ignore = False) -> None:
+    def connect(self, ignore=False) -> None:
 
         if ((not self.open) or ignore) and not self.remote.is_pending:
 
@@ -38,7 +37,8 @@ class RustWebsocket(websocket.WebSocket):
                     self.connected_time = time.time()
                     break
                 except Exception:
-                    self.logger.warning(f"{datetime.now().strftime('%d/%m/%Y %H:%M:%S')} [RustPlus.py] Cannot Connect to server. Retrying in 20 seconds")
+                    self.logger.warning(
+                        f"{datetime.now().strftime('%d/%m/%Y %H:%M:%S')} [RustPlus.py] Cannot Connect to server. Retrying in 20 seconds")
                     time.sleep(20)
 
             self.remote.is_pending = False
@@ -53,7 +53,7 @@ class RustWebsocket(websocket.WebSocket):
         super().close()
         self.open = False
 
-    def send_message(self, message : AppRequest) -> None:
+    def send_message(self, message: AppRequest) -> None:
         """
         Send the Protobuf to the server
         """
@@ -81,12 +81,13 @@ class RustWebsocket(websocket.WebSocket):
 
             except Exception:
                 if self.open:
-                    self.logger.warning(f"{datetime.now().strftime('%d/%m/%Y %H:%M:%S')} [RustPlus.py] Connection interrupted, Retrying")
+                    self.logger.warning(
+                        f"{datetime.now().strftime('%d/%m/%Y %H:%M:%S')} [RustPlus.py] Connection interrupted, Retrying")
                     self.connect(ignore=True)
                     return
                 return
 
-    def handle_message(self, app_message : AppMessage) -> None:
+    def handle_message(self, app_message: AppMessage) -> None:
 
         if app_message.response.seq in self.remote.ignored_responses:
             self.remote.ignored_responses.remove(app_message.response.seq)
@@ -112,7 +113,7 @@ class RustWebsocket(websocket.WebSocket):
         else:
             self.remote.responses[app_message.response.seq] = app_message
 
-    def get_prefix(self, message : str) -> Optional[str]:
+    def get_prefix(self, message: str) -> Optional[str]:
         if self.remote.use_commands:
             if message.startswith(self.remote.command_options.prefix):
                 return self.remote.command_options.prefix
@@ -125,33 +126,39 @@ class RustWebsocket(websocket.WebSocket):
 
         return None
 
-    def is_message(self, app_message) -> bool:
+    @staticmethod
+    def is_message(app_message) -> bool:
         return str(app_message.broadcast.teamMessage.message.message) != ""
 
-    def is_entity_broadcast(self, app_message) -> bool:
+    @staticmethod
+    def is_entity_broadcast(app_message) -> bool:
         return str(app_message.broadcast.entityChanged) != ""
 
-    def is_team_broadcast(self, app_message) -> bool:
+    @staticmethod
+    def is_team_broadcast(app_message) -> bool:
         return str(app_message.broadcast.teamChanged) != ""
 
-    async def _retry_failed_request(self, app_request : AppRequest):
+    async def _retry_failed_request(self, app_request: AppRequest):
         """
         Resends an AppRequest to the server if it has failed
         """
         await self.send_message(app_request)
 
-    def _get_proto_cost(self, app_request) -> int:
+    @staticmethod
+    def _get_proto_cost(app_request) -> int:
         """
         Gets the cost of an AppRequest
         """
-        costs = {"getTime" : 1,"sendTeamMessage" : 2,"getInfo" : 1,"getTeamChat" : 1,"getTeamInfo" : 1,"getMapMarkers" : 1,"getMap" : 5,"setEntityValue" : 1,"getEntityInfo" : 1,"promoteToLeader" : 1}
+        costs = {"getTime": 1, "sendTeamMessage": 2, "getInfo": 1, "getTeamChat": 1, "getTeamInfo": 1,
+                 "getMapMarkers": 1, "getMap": 5, "setEntityValue": 1, "getEntityInfo": 1, "promoteToLeader": 1}
         for request, cost in costs.items():
             if app_request.HasField(request):
                 return cost
 
         raise ValueError()
 
-    def error_present(self, message) -> bool:
+    @staticmethod
+    def error_present(message) -> bool:
         """
         Checks message for error
         """
