@@ -8,18 +8,18 @@ from ..api.structures import RustTime
 
 def format_time(protobuf) -> RustTime:
     def convert_time(time) -> str:
-        HOURS, MINUTES = divmod(time * 60, 60)
+        hours, minutes = divmod(time * 60, 60)
 
-        return f"{int(HOURS)}:0{int(MINUTES)}" if MINUTES <= 9 else f"{int(HOURS)}:{int(MINUTES)}"
+        return f"{int(hours)}:0{int(minutes)}" if minutes <= 9 else f"{int(hours)}:{int(minutes)}"
 
-    SUNRISE = convert_time(protobuf.response.time.sunrise)
-    SUNSET = convert_time(protobuf.response.time.sunset)
-    PARSED_TIME = convert_time(protobuf.response.time.time)
+    sunrise = convert_time(protobuf.response.time.sunrise)
+    sunset = convert_time(protobuf.response.time.sunset)
+    parsed_time = convert_time(protobuf.response.time.time)
 
-    return RustTime(protobuf.response.time.dayLengthMinutes, SUNRISE, SUNSET, PARSED_TIME, protobuf.response.time.time)
+    return RustTime(protobuf.response.time.dayLengthMinutes, sunrise, sunset, parsed_time, protobuf.response.time.time)
 
 
-def format_cood(x, y, map_size) -> tuple:
+def format_coord(x, y, map_size) -> tuple:
     y = map_size - y - 75
     x -= 75
 
@@ -124,42 +124,49 @@ def convert_monument(name: str, override_images: dict) -> Image:
 
 
 def translate_id_to_stack(id: int) -> str:
-    return {
-        "-1018587433": "Animal Fat",
-        "609049394": "Battery - Small",
-        "1719978075": "Bone Fragments",
-        "634478325": "CCTV Camera",
-        "-1938052175": "Charcoal",
-        "-858312878": "Cloth",
-        "204391461": "Coal :(",
-        "-321733511": "Crude Oil",
-        "1568388703": "Diesel Fuel",
-        "1655979682": "Empty Can of Beans",
-        "-1557377697": "Empty Tuna Can",
-        "-592016202": "Explosives",
-        "-930193596": "Fertilizer",
-        "-265876753": "Gun Powder",
-        "317398316": "High Quality Metal",
-        "-1982036270": "High Quality Metal Ore",
-        "-1579932985": "Horse Dung",
-        "996293980": "Human Skull",
-        "1381010055": "Leather",
-        "-946369541": "Low Grade Fuel",
-        "69511070": "Metal Fragments",
-        "-4031221": "Metal Ore",
-        "-1779183908": "Paper",
-        "-804769727": "Plant Fibre",
-        "-544317637": "Research Paper",
-        "-277057363": "Salt Water",
-        "-932201673": "Scrap",
-        "-2099697608": "Stones",
-        "-1581843485": "Sulfur",
-        "-1157596551": "Sulfur Ore",
-        "1523195708": "Targeting Computer",
-        "-1779180711": "Water",
-        "2048317869": "Wolf Skull",
-        "-151838493": "Wood"
-    }[str(id)]
+    try:
+        return {
+            "-1018587433": "Animal Fat",
+            "609049394": "Battery - Small",
+            "1719978075": "Bone Fragments",
+            "634478325": "CCTV Camera",
+            "-1938052175": "Charcoal",
+            "-858312878": "Cloth",
+            "204391461": "Coal :(",
+            "-321733511": "Crude Oil",
+            "1568388703": "Diesel Fuel",
+            "1655979682": "Empty Can of Beans",
+            "-1557377697": "Empty Tuna Can",
+            "-592016202": "Explosives",
+            "-930193596": "Fertilizer",
+            "-265876753": "Gun Powder",
+            "317398316": "High Quality Metal",
+            "-1982036270": "High Quality Metal Ore",
+            "-1579932985": "Horse Dung",
+            "996293980": "Human Skull",
+            "1381010055": "Leather",
+            "-946369541": "Low Grade Fuel",
+            "69511070": "Metal Fragments",
+            "-4031221": "Metal Ore",
+            "-1779183908": "Paper",
+            "-804769727": "Plant Fibre",
+            "-544317637": "Research Paper",
+            "-277057363": "Salt Water",
+            "-932201673": "Scrap",
+            "-2099697608": "Stones",
+            "-1581843485": "Sulfur",
+            "-1157596551": "Sulfur Ore",
+            "1523195708": "Targeting Computer",
+            "-1779180711": "Water",
+            "2048317869": "Wolf Skull",
+            "-151838493": "Wood",
+            "1525520776": "Building Plan",
+            "200773292": "Hammer",
+            "-144417939": "Wire Tool",
+            "363163265" : "Hose Tool"
+        }[str(id)]
+    except KeyError:
+        return "Invalid"
 
 
 def entity_type_to_string(id) -> str:
@@ -174,11 +181,11 @@ def entity_type_to_string(id) -> str:
 
 
 def convert_xy_to_grid(coords: tuple, map_size: float, catch_out_of_bounds: bool = True) -> tuple:
-    GRIDSIZE = 146.25
+    grid_size = 146.25
     grids = list(string.ascii_uppercase) + [f"A{letter}" for letter in list(string.ascii_uppercase)]
 
     if coords[0] > map_size or coords[0] < 0 or coords[1] > map_size or coords[1] < 0:
         if catch_out_of_bounds:
             raise ValueError("Out of bounds")
 
-    return grids[int(coords[0] // GRIDSIZE)], int((map_size - coords[1]) // GRIDSIZE)
+    return grids[int(coords[0] // grid_size)], int((map_size - coords[1]) // grid_size)
